#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-A3v3YiH30QBDf1lN38m4Vh
key:                  pantry-0.8.3-A3v3YiH30QBDf1lN38m4Vh
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  68c0c239aef2e4823091b528735def79
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-A3v3YiH30QBDf1lN38m4Vh
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    ansi-terminal-1.1-C4C2bxKAKLj8NAa2eKLJr base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-3NIiUhkgZT27O5YLSI9hvT
    casa-types-0.0.3-AyX1ZtImoRKBigJeeWpqjE
    conduit-1.3.6.1-GLye9k05ayiLdzpPDhJU0K
    conduit-extra-1.3.8-C49LxeOQ7VlKv4GFzxOpy7 containers-0.6.7
    crypton-1.0.4-3mMbBQHl0K4EgHAKLusoNW
    crypton-conduit-0.2.3-IZXeB68CEKy4GgnAnUXzPf
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-4iPYRUSvQAe62o1xkiS14i
    generic-deriving-1.14.7-CXigfkV378cBxew3OS0ZX4
    hackage-security-0.6.3.2-HePyURz6lumGhANqKHyBrw
    hpack-0.38.0-IJRtnBOwIl1I5DvpwZO1He
    http-client-0.7.19-DXRmxPRORBE3MdmQmSy3IG
    http-client-tls-0.3.6.4-HN3tMmJV0pX8jUBu7FQeO5
    http-conduit-2.3.9.1-9jvrxr3X32oD7zCQ7xobvq
    http-download-0.2.1.0-6s7DLYn5D0qLl5V7qi792A
    http-types-0.12.4-JlSzXn1cYaxE3KCJJlxkWV
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-CsSn6pfoiNDqvqEIqKYSC
    path-0.9.6-7SlKGBssG9F9pBBUmPAkp
    path-io-1.8.2-4bRSGLsMN91Bjf2AxNBJqV
    persistent-2.14.6.0-3kQR514rtT0CT79v4LQQXd
    persistent-sqlite-2.13.2.0-FvaK2XbY6lKDDA5Sk4LcDA
    primitive-0.9.1.0-60b8JX0ZgoSKEjUEtmG9qp
    resourcet-1.2.6-2ZRVpZAaCnB5eaGpQGOamD
    rio-0.1.24.0-4aw46phB15gDVQLXDSkguI
    rio-orphans-0.1.2.0-FB2Xny8rk8S2vlHO6UDTTb
    rio-prettyprint-0.1.8.0-AhSD7l51kVd84IQg1i2XEk
    tar-conduit-0.4.1-4MIgvSYcVe4BFEuHPcsnGM text-2.0.2
    text-metrics-0.3.3-DmVjojWjJokEEJUssChD6S time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-1ix4vuxXmr9HJAwOQozvAF
    unliftio-0.2.25.1-8EuOvwMQbnH3C5Rgo2gyOI
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV
    yaml-0.11.11.2-JaCnvXVwHr1DIN7Fv30Aj1
    zip-archive-0.4.3.2-ZmLoRzZUGMFRlgbvEMXqr

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

